@@ -1,23 +1,41 @@
-github_GET <- function(path, ..., pat = github_pat()) {
-  if (!is.null(pat)) {
-    auth <- httr::authenticate(pat, "x-oauth-basic", "basic")
+github_auth <- function(token) {
+  if (is.null(token)) {
+    NULL
   } else {
-    auth <- NULL
+    httr::authenticate(token, "x-oauth-basic", "basic")
   }
+}
 
-  req <- httr::GET("https://api.github.com/", path = path, auth, ...)
-
+github_response <- function(req) {
   text <- httr::content(req, as = "text")
   parsed <- jsonlite::fromJSON(text, simplifyVector = FALSE)
 
   if (httr::status_code(req) >= 400) {
-    stop("Request failed (", httr::status_code(req), ")\n", parsed$message,
-      call. = FALSE)
+    errors <- vapply(parsed$errors, `[[`, "message", FUN.VALUE = character(1))
+
+    stop(
+      parsed$message, " (", httr::status_code(req), ")\n",
+      paste("* ", errors, collapse = "\n"),
+      call. = FALSE
+    )
   }
 
   parsed
 }
 
+github_GET <- function(path, ..., pat = github_pat()) {
+  auth <- github_auth(pat)
+  req <- httr::GET("https://api.github.com/", path = path, auth, ...)
+  github_response(req)
+}
+
+github_POST <- function(path, body, ..., pat = github_pat()) {
+  auth <- github_auth(pat)
+  req <- httr::POST("https://api.github.com/", path = path, body = body, auth,
+    encode = "json", ...)
+  github_response(req)
+}
+
 github_rate_limit <- function() {
   req <- github_GET("rate_limit")
   core <- req$resources$core
@@ -37,7 +55,8 @@ github_tag <- function(username, repo, ref = "master") {
 
 #' Retrieve Github personal access token.
 #'
-#' Looks in env var \code{GITHUB_PAT}.
+#' A github personal access token
+#' Looks in env var \code{GITHUB_PAT}
 #'
 #' @keywords internal
 #' @export
