@@ -5,7 +5,6 @@
 #' @return TRUE if your development environment is correctly set up, otherwise
 #'   returns an error.
 #' @export
-#' @keywords internal
 #' @examples
 #' has_devel()
 has_devel <- function() {
@@ -24,3 +23,16 @@ has_devel <- function() {
   stopifnot(.C(dll$foo, 0L)[[1]] == 1L)
   TRUE
 }
+
+check_build_tools <- function(pkg = ".") {
+  pkg <- as.package(pkg)
+  if (!file.exists(file.path(pkg$path, "src"))) return(TRUE)
+
+  check <- getOption("buildtools.check", NULL)
+  if (!is.null(check)) {
+    check("Installing R package from source")
+  } else {
+    # Outside of Rstudio and don't have good heuristic
+    TRUE
+  }
+}
