@@ -33,10 +33,12 @@
 #' @param dependencies \code{logical} indicating to also install uninstalled
 #'   packages which this \code{pkg} depends on/links to/suggests. See
 #'   argument \code{dependencies} of \code{\link{install.packages}}.
+#' @param upgrade_dependencies If \code{TRUE}, the default, will also update
+#'   any out of date dependencies.
 #' @param build_vignettes if \code{TRUE}, will build vignettes. Normally it is
 #'   \code{build} that's responsible for creating vignettes; this argument makes
 #'   sure vignettes are built even if a build never happens (i.e. because
-#'   \code{local = TRUE}.
+#'   \code{local = TRUE}).
 #' @param keep_source If \code{TRUE} will keep the srcrefs from an installed
 #'   package. This is useful for debugging (especially inside of RStudio).
 #'   It defaults to the option \code{"keep.source.pkgs"}.
@@ -52,7 +54,8 @@
 #'   set.
 install <- function(pkg = ".", reload = TRUE, quick = FALSE, local = TRUE,
                     args = getOption("devtools.install.args"), quiet = FALSE,
-                    dependencies = NA, build_vignettes = FALSE,
+                    dependencies = NA, upgrade_dependencies = TRUE,
+                    build_vignettes = FALSE,
                     keep_source = getOption("keep.source.pkgs"),
                     threads = getOption("Ncpus", 1),
                     ...) {
@@ -60,13 +63,16 @@ install <- function(pkg = ".", reload = TRUE, quick = FALSE, local = TRUE,
   pkg <- as.package(pkg)
   check_build_tools(pkg)
 
-  if (!quiet) message("Installing ", pkg$package)
+  if (!quiet) {
+    message("Installing ", pkg$package)
+  }
 
   # If building vignettes, make sure we have all suggested packages too.
   if (build_vignettes && missing(dependencies)) {
     dependencies <- TRUE
   }
-  install_deps(pkg, dependencies = dependencies, threads = threads, ...)
+  install_deps(pkg, dependencies = dependencies, upgrade = upgrade_dependencies,
+    threads = threads, ...)
 
   # Build the package. Only build locally if it doesn't have vignettes
   has_vignettes <- length(tools::pkgVignettes(dir = pkg$path)$docs > 0)
@@ -91,20 +97,29 @@ install <- function(pkg = ".", reload = TRUE, quick = FALSE, local = TRUE,
   R(paste("CMD INSTALL ", shQuote(built_path), " ", opts, sep = ""),
     quiet = quiet)
 
-  if (reload) reload(pkg, quiet = quiet)
+  if (reload) {
+    reload(pkg, quiet = quiet)
+  }
   invisible(TRUE)
 }
 
 #' Install package dependencies if needed.
 #'
 #' @inheritParams install
+#' @inheritParams package_deps
 #' @param ... additional arguments passed to \code{\link{install.packages}}.
 #' @export
 #' @examples
 #' \dontrun{install_deps(".")}
 install_deps <- function(pkg = ".", dependencies = NA,
                          threads = getOption("Ncpus", 1),
-                         ...) {
-  pkg <- dev_package_deps(pkg, dependencies = dependencies)
-  update(pkg, Ncpus = threads, ...)
+                         repos = getOption("repos"),
+                         type = getOption("pkgType"),
+                         ...,
+                         upgrade = TRUE,
+                         quiet = FALSE) {
+
+  pkg <- dev_package_deps(pkg, repos = repos, dependencies = dependencies,
+    type = type)
+  update(pkg, ..., Ncpus = threads, quiet = quiet, upgrade = upgrade)
 }
